@@ -1,15 +1,14 @@
 package Datahub::Factory::Importer::KMSKA;
 
-use strict;
-use warnings;
+use Datahub::Factory::Sane;
+
+our $VERSION = '0.100';
 
 use Moo;
 use Catmandu;
-
 use Config::Simple;
-
-use Datahub::Factory::Importer::TMS::Index;
-use Datahub::Factory::Importer::PIDS;
+use Datahub::Factory::Importer::KMSKA::TMS::Index;
+use namespace::clean;
 
 with 'Datahub::Factory::Importer';
 
@@ -17,23 +16,19 @@ has db_host     => (is => 'ro', required => 1);
 has db_name     => (is => 'ro', required => 1);
 has db_user     => (is => 'ro', required => 1);
 has db_password => (is => 'ro', required => 1);
-
-has tms      => (is => 'lazy');
+has generate_temp_tables => (is => 'ro', default => 1);
 
 sub _build_importer {
     my $self = shift;
     my $dsn = sprintf('dbi:mysql:%s', $self->db_name);
-    # Add indices
-    $self->logger->info('Creating indices on TMS tables.');
-    Datahub::Factory::Importer::TMS::Index->new(
-        db_host => $self->db_host,
-        db_name => $self->db_name,
-        db_user => $self->db_user,
-        db_password => $self->db_password
-    );
-    my $query = 'select * from vgsrpObjTombstoneD_RO;';
+
+    my $query = 'select * from CITvgsrpObjTombstoneD_RO;';
     my $importer = Catmandu->importer('DBI', dsn => $dsn, host => $self->db_host, user => $self->db_user, password => $self->db_password, query => $query, encoding => ':iso-8859-1');
-    $self->prepare();
+
+    if ($self->generate_temp_tables) {
+        $self->prepare();
+    }
+
     return $importer
 }
 
@@ -48,6 +43,14 @@ sub prepare {
     $self->__dimensions();
     $self->logger->info('Adding "subjects" temporary table.');
     $self->__subjects();
+    $self->logger->info('Adding "constituents" temporary table.');
+    $self->__constituents();
+    $self->logger->info('Adding "datapids" temporary table.');
+    $self->__datapids();
+    $self->logger->info('Adding "representationpids" temporary table.');
+    $self->__representationpids();
+    $self->logger->info('Adding "workpids" temporary table.');
+    $self->__workpids();
 }
 
 sub prepare_call {
@@ -106,49 +109,48 @@ sub merge_call {
     }
 }
 
+sub __constituents {
+    my $self = shift;
+    $self->prepare_call('SELECT * FROM vconstituents', 'constituents');
+}
+
 sub __classifications {
     my $self = shift;
-    $self->prepare_call('select ClassificationID as _id, Classification as term from Classifications', 'classifications');
+    $self->prepare_call('SELECT * FROM vclassifications', 'classifications');
 }
 
 sub __period {
     my $self = shift;
-    $self->prepare_call('select ObjectID as _id, Period as term from ObjContext', 'periods')
+    $self->prepare_call('SELECT * FROM vperiods', 'periods');
+}
+
+sub __datapids {
+    my $self = shift;
+    $self->prepare_call('SELECT * FROM vdatapids', 'datapids');
+}
+
+sub __workpids {
+    my $self = shift;
+    $self->prepare_call('SELECT * FROM vworkpids', 'workpids');
+}
+
+sub __representationpids {
+    my $self = shift;
+    $self->prepare_call('SELECT * FROM vperiods', 'representationpids');
 }
 
 sub __dimensions {
     my $self = shift;
-    my $query = "SELECT o.ObjectID as objectid, d.Dimension as dimension, t.DimensionType as type, e.Element as element, u.UnitName as unit
-    FROM vgsrpObjTombstoneD_RO o
-    LEFT JOIN
-        DimItemElemXrefs x ON x.ID = o.ObjectID
-    INNER JOIN
-        Dimensions d ON d.DimItemElemXrefID = x.DimItemElemXrefID
-    INNER JOIN
-        DimensionUnits u ON u.UnitID = d.PrimaryUnitID
-    INNER JOIN
-        DimensionTypes t ON t.DimensionTypeID = d.DimensionTypeID
-    INNER JOIN
-        DimensionElements e ON e.ElementID = x.ElementID
-    WHERE
-        x.TableID = '108'
-    AND 
-        x.ElementID = '3';";
-    $self->merge_call($query, 'dimensions', 'dimensions');
+    $self->merge_call('SELECT * FROM vdimensions', 'dimensions', 'dimensions');
 }
 
 sub __subjects {
     my $self = shift;
-    my $query = "SELECT o.ObjectID as objectid, t.Term as subject
-    FROM Terms t, vgsrpObjTombstoneD_RO o, ThesXrefs x, ThesXrefTypes y
-    WHERE
-    x.TermID = t.TermID and
-    x.ID = o.ObjectID and
-    x.ThesXrefTypeID = y.ThesXrefTypeID and
-    y.ThesXrefTypeID = 30;"; # Only those from the VKC website
-    $self->merge_call($query, 'subjects', 'subjects');
+    $self->merge_call('SELECT * FROM vsubjects', 'subjects', 'subjects');
 }
+
 1;
+
 __END__
 
 =encoding utf-8
@@ -234,4 +236,4 @@ L<Datahub::Factory>
 L<Datahub::Factory::Importer::TMS>
 L<Catmandu>
 
-=cut
\ No newline at end of file
+=cut
